#
# spec file for package goocanvas2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Option to easily enable/disable introspection building.
%define with_introspection 1

%define _name   goocanvas
Name:           goocanvas2
Version:        2.0.4
Release:        4.2
Summary:        A Cairo-based canvas widget for GTK+
License:        LGPL-2.0-only
Group:          Development/Libraries/GNOME
URL:            https://wiki.gnome.org/GooCanvas
Source0:        https://download.gnome.org/sources/goocanvas/2.0/%{_name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM fix-gcc14-build.patch -- Fix building with GCC 14
Patch1:         fix-gcc14-build.patch

BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
%if %{with_introspection}
BuildRequires:  gobject-introspection-devel
%endif

%description
GooCanvas is a canvas widget for GTK+ that uses the Cairo 2D library
for drawing. It has an optional model/view split, and uses interfaces
for items and models, so any application object can be turned into a
canvas item or model.

%package devel
Summary:        Development files for GooCanvas
Group:          Development/Libraries/GNOME
Requires:       libgoocanvas-2_0-9 = %{version}
%if %{with_introspection}
Requires:       typelib-1_0-GooCanvas-2_0 = %{version}
%endif

%description devel
GooCanvas is a canvas widget for GTK+ that uses the Cairo 2D library
for drawing.

This subpackage contains the header files for developing
applications that want to make use of libgoocanvas.

%package -n libgoocanvas-2_0-9
Summary:        A Cairo-based canvas widget for GTK+
Group:          System/Libraries
# Needed to make lang package installable
Provides:       %{_name}2 = %{version}

%description -n libgoocanvas-2_0-9
GooCanvas is a canvas widget for GTK+ that uses the Cairo 2D library
for drawing. It has an optional model/view split, and uses interfaces
for items and models, so any application object can be turned into a
canvas item or model.

%if %{with_introspection}
%package -n typelib-1_0-GooCanvas-2_0
Summary:        Introspection bindings for GooCanvas
Group:          System/Libraries

%description -n typelib-1_0-GooCanvas-2_0
GooCanvas is a canvas widget for GTK+ that uses the Cairo 2D library
for drawing.

This package provides the GObject Introspection bindings for GooCanvas.
%endif

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%configure \
    --disable-static \
%if %{with_introspection}
    --enable-introspection
%else
    --disable-introspection
%endif
%make_build

%install
%make_install
rm %{buildroot}%{_libdir}/*.*a
%find_lang goocanvas2

%ldconfig_scriptlets -n libgoocanvas-2_0-9

%files -n libgoocanvas-2_0-9
%doc AUTHORS NEWS README TODO
%{_libdir}/*.so.*

%if %{with_introspection}
%files -n typelib-1_0-GooCanvas-2_0
%{_libdir}/girepository-1.0/GooCanvas-2.0.typelib
%endif

%files devel
%{_includedir}/%{_name}-2.0/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%if %{with_introspection}
%{_datadir}/gir-1.0/GooCanvas-2.0.gir
%endif
%doc %{_datadir}/gtk-doc/

%files lang -f goocanvas2.lang

%changelog
* Thu Jul 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-gcc14-build.patch: Fix build with gcc 14.
- Use ldconfig_scriptlets for post(un) handling.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Feb  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Rename package goocanvas2, new compat package as upstream moved
  to new api.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Oct 13 2017 jengelh@inai.de
- Update package descriptions. Drop redundant %%clean section.
* Tue Oct 10 2017 luc14n0@linuxmail.org
- Update to version 2.0.4:
  + Support latest gtk-doc and add an index (bgo#788436).
- Update Url to https://wiki.gnome.org/GooCanvas: current GooCanvas
  home page.
* Thu Aug 31 2017 zaitor@opensuse.org
- Update to version 2.0.3:
  + Fixed stuck pointer grab bug (bgo#711709).
  + Fixed several introspection problems.
  + Removed use of a lot of deprecated GTK+ API.
* Mon Nov  4 2013 dimstar@opensuse.org
- Update to version 2.0.2:
  + Fixed the drawing code to work with GTK+ 3.10.
  + Added/fixed a few introspection flags. GooCanvasLineDash should
    now be usable via introspection.
- Drop goocanvas-introspection.patch: fixed upstream.
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Sat Mar 30 2013 dimstar@opensuse.org
- Re-enable introspection:
  + change with_introspection to 1.
  + Add goocanvas-introspection.patch: fix building the
    introspection.
* Wed Mar 27 2013 dimstar@opensuse.org
- Introduce with_introspection defines to conditionally:
  + Add gobject-introspection-devel BuildRequires.
  + Pass --enable-introspection/--disable-introspection to
    configure.
  + Create typelib-1_0-GooCanvas-2_0 subpackage (and require it
    from the -devel package).
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GooCanvas-2_0 subpackage.
- Add typelib-1_0-GooCanvas-2_0 Requires to devel subpackage.
* Sun Oct  9 2011 zaitor@opensuse.org
- Update to version 2.0.1:
  + Added GObject introspection support, though a few issues
    remain.
  + Fixed bounds calculation of text items in tables, when "height"
    is set.
  + Fixed layout of center/right-aligned text in tables.
  + Improved handling of image pixbuf sizes when using units other
    than pixels.
  + Added GdkRGBA variants of all color properties.
- Add gobject-introspection-devel BuildRequires to build
  introspection data.
* Wed Jun  8 2011 vuntz@opensuse.org
- Add a goocanvas Provides to libgoocanvas-2_0-9 so that the lang
  package is installable.
* Wed Jun  1 2011 dimstar@opensuse.org
- Update to version 2.0.0:
  + Ported to GTK+ 3.0.
  + Can be installed with GooCanvas 1.0.x without conflicting.
- Move to pkgconfig()-style BuildRequires and GNOME 3:
  + Old ones: cairo-devel, gtk2-devel.
  + New ones: cairo, gtk+-3.0.
- Rename libgoocanvas3 to libgoocanvas-2_0-9 following the library
  name change.
- Do not add explicit Requires for cairo-devel, gtk2-devel,
  pkg-config in the devel subpackage: they will automatically be
  added the pkgconfig() way.
- Remove Provides/Obsoletes for goocanvas-doc and goocanvas, as
  they were only needed for goocanvas 1.x.
- Change Requires for lang subpackage to a Recommends, as the
  translations are not mandatory.
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 1.0.0:
  + Added "alpha" property to GooCanvasImage to set opacity.
  + Allow setting clip path to NULL to reset it.
  + Allow setting line dash to NULL to reset it.
  + Handle RTL direction better in GooCanvasTable.
  + Fixed GooCanvasGroup bug: use the correct scale argument in
    paint.
  + Fixed GooCanvasPolyline bug: update arrows when line width
    changes.
  + Fixed static items bug: don't clip incorrectly.
  + Improved performance a bit when creating lots of items.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 0.15:
  + Fixed a bug that caused a hang when using GooCanvasWidget with
    accessibility support turned on.
  + Added "scale-to-fit" property to GooCanvasImage, to scale the
    image to the "width" and "height" settings, instead of just
    clipping.
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 0.14:
  + Added support for tooltips.
  + Added "x", "y", "width" and "height" properties to items that
    didn't have them.
  + Fixed bug in goo_canvas_convert_from_item_space().
  + Added "scroll-event" signal to GooCanvasItem.
- Remove unneeded BuildRequires: gtk-doc.
- Remove goocanvas package since it only contains data that should
  be in libgoocanvas3 now. Have libgoocanvas3 Obsolete/Provide it.
- Merge -doc into -devel as it only contained gtk-doc
- Have the devel package requires libgoocanvas3.
- Remove AutoReqProv: it's default now.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Dec 31 2008 mboman@suse.de
- Update to version 0.13:
  + New GooCanvasGrid item for drawing grids on the canvas.
  + Support for static items that don't move as the canvas is zoomed
    and scrolled (this is a bit experimental).
  + Font hinting is not turned off any more - this means smaller text should
    be more readable. Hopefully it doesn't affect text layout.
  + Fixed a few GooCanvasTable drawing bugs.
  + Fixed GooCanvasText drawing, when align is set.
  + Fixed GooCanvasPolyline is_item_at() code, so the fill isn't tested.
  + Added "animation-finished" signals to GooCanvasItem & Model.
* Fri Oct  3 2008 mboman@suse.de
- Update to version 0.12:
  + Fixed redraws of tables after updates.
  + Fixed problems compiling with libtool 2.2.
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.11:
  + Use the tables' fill and stroke colors to paint its grid and
    background
  + Emit "children_changed" ATK signal when child items
    added/removed.
  + Fixed bug when clipping the entire canvas
  +o Got rid of the XXX_DISABLE_DEPRECATED compilation flags.
* Wed Aug 20 2008 maw@suse.de
- Add goocanvas-g_signal.patch, which updates some deprecated
  code.
* Mon Jun 30 2008 maw@suse.de
- Update to version 0.10:
  + Added support for a border and grid lines to GooCanvasTable,
    with "horz-grid-line-width", "vert-grid-line-width",
    "x-border-spacing", and "y-border-spacing" properties
  + Added "clear-background" property to GooCanvas, to allow
    subclasses to paint their own background if desired
  + Fixed crash when rendering a GooCanvasTable that hasn't been
    updated
  + Fixed possible infinite loop in GooCanvasTable layout
  + Added goo_canvas_text_get_natural_extents() to get the natural
    extents of the text
  + Made "stroke-color-rgba" and "fill-color-rgba" properties
    read/write
  + Added goo_canvas_item_get_simple_transform() and
    goo_canvas_item_model_get_simple_transform(), which do the
    opposite of the set_simple_transform() functions
  + Improved documentation on general architecture and creating
    new items.
* Wed Dec  5 2007 maw@suse.de
- Import into autobuild
- Improve packaging so as to pass internal rpmlist checks.
* Thu Nov  1 2007 maw@suse.de
- Initial package.
